@@ -1,4 +1,5 @@
 import itertools
+import math
 import time
 from collections import OrderedDict, Iterable
 from typing import Optional
@@ -55,25 +56,25 @@ class Report:
         """
         self.create_report_html()
         from orangewidget.report.owreport import HAVE_REPORT
-        if not HAVE_REPORT:
+
+        report = self._get_designated_report_view()
+        if not HAVE_REPORT and not report.have_report_warning_shown:
             QMessageBox.critical(
                 None, "Missing Component",
-                "Your installation of Orange contains neither WebEngine nor "
-                "WebKit.\n\n"
+                "Orange can not display reports, because your installation "
+                "contains neither WebEngine nor WebKit.\n\n"
                 "If you installed Orange with conda or pip, try using another "
-                "PyQt distribution.\n\n"
+                "PyQt distribution. "
                 "If you installed Orange with a standard installer, please "
                 "report this bug."
             )
-            return None
+            report.have_report_warning_shown = True
 
-        if HAVE_REPORT:
-            report = self._get_designated_report_view()
-            # Should really have a signal `report_ready` or similar to decouple
-            # the implementations.
-            report.make_report(self)
-            report.show()
-            report.raise_()
+        # Should really have a signal `report_ready` or similar to decouple
+        # the implementations.
+        report.make_report(self)
+        report.show()
+        report.raise_()
 
     def get_widget_name_extension(self):
         """
@@ -628,8 +629,17 @@ def get_icon_html(icon: QIcon, size: QSize) -> str:
         return ""
     pixmap.save(buffer, "PNG")
     buffer.close()
+
+    dpr = pixmap.devicePixelRatioF()
+    if dpr != 1.0:
+        size_ = pixmap.size() / dpr
+        size_part = ' width="{}" height="{}"'.format(
+            int(math.floor(size_.width())), int(math.floor(size_.height()))
+        )
+    else:
+        size_part = ''
     img_encoded = byte_array.toBase64().data().decode("utf-8")
-    return '<img src="data:image/png;base64,{}"/>'.format(img_encoded)
+    return '<img src="data:image/png;base64,{}"{}/>'.format(img_encoded, size_part)
 
 
 def colored_square(r, g, b):
